__title__ = "lpipe"
__version__ = "3.0.1"
__summary__ = "AWS Lambda framework for writing clear, minimal Python FAAS"
__author__ = "Charlie Mathews"
__author_email__ = "cmathews@mintel.com"
__maintainer__ = "Charlie Mathews"
__maintainer_email__ = "cmathews@mintel.com"
__uri__ = "https://github.com/mintel/lpipe"
